@@ -189,6 +189,30 @@ def to_filehandle(fname, flag='r', return_opened=False):
     return fh, opened
   return fh
 
+def tsplit(s, sep):
+  def tsplit(s, sep):
+    """Splits a string like split but allows for several char delimiters
+    Example:
+    >>> tsplit("hello,my|name+is-bob", (",", "|", "+", "-"))
+    ['hello', 'my', 'name', 'is', 'bob']
+    >>> tsplit("hello,my|name+is-bob", ",|+-")
+    ['hello', 'my', 'name', 'is', 'bob']
+    >>> tsplit("hello,my|name+is-bob", list(",|+-"))
+    ['hello', 'my', 'name', 'is', 'bob']
+    >>> tsplit("hello,my|name+is-bob", "+")
+    ['hello,my|name', 'is-bob']
+
+    Arguments:
+    - `s`: string to separate
+    - `sep`: separators
+    """
+    stack = [s]
+    for char in sep:
+        pieces = []
+        for substr in stack:
+            pieces.extend(substr.split(char))
+        stack = pieces
+    return stack
 
 def openfile(fname=None,intent='r'):
   if fname == None or fname == '-' or fname == '':
@@ -349,7 +373,7 @@ def handle_math(str,orden=0):
   Si orden =0 => bib -> html 
   Si orden =1 => html -> bib
   """
-  mathexp= ([ (re.compile(r'\^([^{]){',re.I)  ,r'<sup>\1</sup>')
+  mathexp= ([ (re.compile(r'\^([^{])',re.I)  ,r'<sup>\1</sup>')
              ,(re.compile(r'\^{([^{]+)}',re.I),r'<sup>\1</sup>')
              ,(re.compile(r'_([^{]+){',re.I)  ,r'<sub>\1</sub>')
              ,(re.compile(r'_{([^{]+)}',re.I) ,r'<sub>\1</sub>')
@@ -396,6 +420,7 @@ def removebraces(str):
 # @return the capitalized string (first letter is capitalized), rest are capitalized
 # only if capitalized inside braces
 capitalize_rex = re.compile('({\w*})')
+cap_rex = re.compile('{([a-zA-Z]*)}')
 def capitalizestring(data):
   ss_list = capitalize_rex.split(data)
   ss = ''
@@ -405,12 +430,11 @@ def capitalizestring(data):
 
 	 # keep phrase's capitalization the same
     if check.find('{') == 0:
-      ss+= removebraces(phrase)
+      ss+= cap_rex.sub(r'\1',phrase)
     else:
       # first word --> capitalize first letter (after spaces)
       if count == 0:
         ss+= phrase.capitalize() 
-#         ss+= check.capitalize() 
       else:
         ss+= phrase.lower() 
       count+= 1
